@@ -1,8 +1,7 @@
-from typing import List, Optional
+from typing import List
 
 from conductor.client.configuration.configuration import Configuration
 from conductor.client.http.models.schema_def import SchemaDef
-from conductor.client.http.rest import ApiException
 from conductor.client.orkes.orkes_base_client import OrkesBaseClient
 from conductor.client.schema_client import SchemaClient
 
@@ -24,4 +23,4 @@ class OrkesSchemaClient(OrkesBaseClient, SchemaClient):
         self.schemaApi.delete_schema_by_name_and_version(name=schema_name, version=version)
 
     def delete_schema_by_name(self, schema_name: str) -> None:
-        self.schemaApi.delete_schema_by_name(name=schema_name)
\ No newline at end of file
+        self.schemaApi.delete_schema_by_name(name=schema_name)
